################################################################################
# Supplement B for ``Selection and Fusion of Categorical Predictors with L0-Type 
# Penalties''
# Margret-Ruth Oelker and Gerhard Tutz
# 2014, June 2nd

################################################################################
# R-code for Section 5: Unemployment Rates in Germany
# R version 3.0.2, 19.10.2013


load("SM14-AK002.oelker.tutz.suppB.RData") 
library(gvcm.cat) # version 1.6

# formula
URf0  <- unemployment ~ v(1, state, n="L0") + yearnew

# models
m1 <- gvcm.cat(URf0, URgerman, family=Gamma(), plot=TRUE,
  control=cat_control(lambda.upper=9, gama=36, steps=1000))   

m2 <- gvcm.cat(URf0, URgerman, family=Gamma(), plot=TRUE, 
  tuning=list(lambda=seq(0,2,length.out=40), specific=borders),
  control=cat_control(lambda.upper=20, gama=26, adapted.weights=FALSE, steps=1000))    
  
# Note: steps=1000 indicates that the computation of 400 additional model fits 
# to obtain accurate coefficient paths - may take some time. 


# coefficient paths
par(cex=1.3)
plot(m1, main="gamma, L0, var int", ylim=c(1.8,3.0), indent=0.05)
plot(m2, main="gamma, L0, var int, borders", ylim=c(1.8,3.0), indent=0.05)


